@@ -1,17 +1,19 @@
 library(CodeDepends)
 
- # With cacher1.R, letters appears, but doesn't show up in the graph.
- # sc = readScript("cacher1.R")
 
-sc = readScript(system.file("samples", "cacherCode", "cacher.R", package = "CodeDepends"))
+sc = readScript(system.file("samples", "cacherCode", "cacher1.R", package = "CodeDepends"))
 info = getInputs(sc)
 vars = getVariables(info)
+stopifnot(identical(vars, c("tmp", "cities", "classes", "vars", "data", "data", #second one is an update
+                            "estimates", "effect", "stderr")))
 
 o = structure(lapply(vars, CodeDepends:::getDependsOn, info, vars), names = vars)
 
+g = makeVariableGraph(system.file("samples", "cacherCode", "cacher1.R", package = "CodeDepends"))
 g = makeVariableGraph(system.file("samples", "cacherCode", "cacher2.R", package = "CodeDepends"))
 
 
+
 # info[[5]] should have data as an update, not an output
 # And should also have names<- as a function.
 # So data would be an update variable, implying it is an input
